@@ -6,7 +6,6 @@ import errno
 import argparse
 import logging
 import threading
-import tarfile
 import filecmp
 import shutil
 import subprocess
@@ -16,7 +15,7 @@ import sys
 
 try:
     import git
-    import semantic_version as semver
+    import semantic_version as semver # lgtm[py/unused-import]
 except ImportError:
     print("error: zkg failed to import one or more dependencies:\n"
           "\n"
@@ -37,6 +36,19 @@ if os.path.isdir(ZEEK_PYTHON_DIR):
 else:
     ZEEK_PYTHON_DIR = None
 
+# Similarly, make Zeek's binary installation path available by
+# default. This helps package installations succeed that require
+# e.g. zeek-config for their build process.
+ZEEK_BIN_DIR = '@ZEEK_BIN_DIR@'
+if os.path.isdir(ZEEK_BIN_DIR):
+    try:
+        if ZEEK_BIN_DIR not in os.environ['PATH'].split(os.pathsep):
+            os.environ['PATH'] = ZEEK_BIN_DIR + os.pathsep + os.environ['PATH']
+    except KeyError:
+        os.environ['PATH'] = ZEEK_BIN_DIR
+else:
+    ZEEK_BIN_DIR = None
+
 # Also when bundling with Zeek, use directories in the install tree
 # for storing the zkg configuration and its variable state:
 ZEEK_ZKG_CONFIG_DIR = '@ZEEK_ZKG_CONFIG_DIR@'
@@ -1827,9 +1839,7 @@ def _fill_metadata_version(pkginfo_name_metadata_version, info_metadata):
 
 def cmd_config(manager, args, config, configfile):
     if args.config_param == 'all':
-        from io import StringIO
-
-        out = StringIO()
+        out = io.StringIO()
         config.write(out)
         print(out.getvalue())
         out.close()
